#!/bin/sh
##################################################################
# Licensed Materials - Property of IBM
#
# IBM Financial Crimes Insight with Watson PID 5900-A0H
# IBM Financial Crimes Insight with Watson, Private PID 5737-E41
#
# (C) Copyright IBM Corp. 2017
#
# US Government Users Restricted Rights - Use, duplication or
# disclosure restricted by GSA ADP Schedule Contract with
# IBM Corp.
##################################################################

# Input variables
AMBARI_HOSTNAME=$1	# Ambari hostname
AMBARI_USER=$2		# Ambari admin user
AMBARI_USER_PW=$3	# Ambari admin user password


# Set defaults if not set
[[ "${AMBARI_HOSTNAME}" = "" ]]   	&& MEDIA_DIR="`hostname -f`"
[[ "${AMBARI_USER}" = "" ]]   		&& MEDIA_DIR="admin" 
[[ "${AMBARI_USER_PW}" = "" ]]   	&& MEDIA_DIR="admin"

# Capture the current working directory
SCRIPT_DIR=$(cd -P -- "$(dirname -- "$0")" && pwd -P)

# Set aliases
alias log.info='echo [INFO][line $LINENO] ${INSTALL_STEP} - '
alias log.error='echo [ERROR][line $LINENO] ${INSTALL_STEP} - '
alias log.warn='echo [WARNING][line $LINENO] ${INSTALL_STEP} - '

##################################################################

INSTALL_STEP="Restart Cluster"
log.info "=================================================================================="
log.info "Restarting cluster."
log.info "=================================================================================="
# Stop all cluster services
log.info "Stopping all services in the cluster" && echo
curl -H 'X-Requested-By: ambari' -X PUT -u ${AMBARI_USER}:${AMBARI_USER_PW} -d '{"RequestInfo": {"context" : "put services into STOPPED STATE"}, "Body": {"ServiceInfo": {"state": "INSTALLED"}}}' https://${AMBARI_HOSTNAME}:8081/api/v1/clusters/fcicluster/services/ > stop.services.request
cat stop.services.request

# Determine stop cluster request URL
stop_services_url=`cat stop.services.request | grep "href" | head -n 1 | sed 's/^.*: \"//' | tr -d \",`
echo $stop_services_url

# Check stop services status
echo && log.info "Checking cluster stop services request status."
stop_services_status=""
while [ "$stop_services_status" != "COMPLETED" ];
do 
	if [ "$stop_services_status" = "FAILED" ]; then
		echo && log.error "Terminating.  Unable to stop cluster. Check the Ambari logs." && echo
		exit 1
	elif [ "$stop_services_status" = "ABORTED" ]; then
		echo && log.error "The cluster stop request has aborted. Please check the Ambari logs." && echo
		exit 1
	else
		stop_services_status=`curl -N -u ${AMBARI_USER}:${AMBARI_USER_PW} -s -H "X-Requested-By: ambari" -X GET $stop_services_url | head -n 24 | grep "request_status" | sed 's/^.*: \"//' | tr -d \",`
		percent_complete=`curl -N -u ${AMBARI_USER}:${AMBARI_USER_PW} -s -H "X-Requested-By: ambari" -X GET $stop_services_url | head -n 24 | grep "progress_percent" | sed 's/^.*: \"//' | tr -d \", | sed 's/^.*: //' | grep -o '^[0-9]*\.[0-9]'`
		log.info "`date +%Y/%m/%d-%H:%M:%S` - Stop services request is currently: $stop_services_status"	
    	log.info "`date +%Y/%m/%d-%H:%M:%S` - Percent Complete: ${percent_complete}% - Checking again in 20 seconds..."
		sleep 20s
	fi
done

# Stop all cluster services complete
echo && log.info "Stopping of the cluster services is complete."

# Start all cluster services
log.info "Starting all services in the cluster" && echo
curl -H 'X-Requested-By: ambari' -X PUT -u ${AMBARI_USER}:${AMBARI_USER_PW} -d '{"RequestInfo": {"context" :"put services into STARTED STATE"}, "Body": {"ServiceInfo": {"state": "STARTED"}}}' https://${AMBARI_HOSTNAME}:8081/api/v1/clusters/fcicluster/services > start.services.request
cat start.services.request

# Determine start cluster request URL
start_services_url=`cat start.services.request | grep "href" | head -n 1 | sed 's/^.*: \"//' | tr -d \",`
echo $start_services_url

# Check start services status
echo && log.info "Checking cluster start services request status."
start_services_status=""
while [ "$start_services_status" != "COMPLETED" ];
do 
	if [ "$start_services_status" = "FAILED" ]; then
		echo && log.error "Terminating.  Unable to start cluster. Check the Ambari logs." && echo
		exit 1
	elif [ "$start_services_status" = "ABORTED" ]; then
		echo && log.error "The cluster start request has aborted. Please check the Ambari logs." && echo
		exit 1
	else
		start_services_status=`curl -N -u ${AMBARI_USER}:${AMBARI_USER_PW} -s -H "X-Requested-By: ambari" -X GET $start_services_url | head -n 24 | grep "request_status" | sed 's/^.*: \"//' | tr -d \",`
		percent_complete=`curl -N -u ${AMBARI_USER}:${AMBARI_USER_PW} -s -H "X-Requested-By: ambari" -X GET $start_services_url | head -n 24 | grep "progress_percent" | sed 's/^.*: \"//' | tr -d \", | sed 's/^.*: //' | grep -o '^[0-9]*\.[0-9]'`
		log.info "`date +%Y/%m/%d-%H:%M:%S` - Start services request status is currently: $start_services_status"	
    	log.info "`date +%Y/%m/%d-%H:%M:%S` - Percent Complete: ${percent_complete}% - Checking again in 20 seconds..."
		sleep 20s
	fi
done

# Cleanup
/bin/rm -f create.cluster.request start.services.request stop.services.request


echo
exit 0