#!/bin/bash

# sample invocation for rangerugsync: 
#
# 	config-ranger-plugin-trust.sh \
#		$javaTrustPassword \
#		$rangerKeyStorePassword \
#		rangerugsync \
#		/usr/iop/current/ranger-usersync/conf \
#		unixauthservice.jks \
#		$ugsyncKeyStorePassword \
#		mytruststore.jks\
#		$ugsyncTrustStorePassword
#
# sample invocation for rangerkms:
#
# 	config-ranger-plugin-trust.sh \
#		$javaTrustPassword \
#		$rangerKeyStorePassword \
#		rangerkmsagent \
#		/usr/iop/current/ranger-kms/conf \
#		ranger-plugin-keystore.jks \
#		$kmsKeyStorePassword \
#		ranger-plugin-truststore.jks\
#		$kmsTrustStorePassword


#-------------------------
# getJavaTrustStore
#------------------------
function getJavaTrustStore() {
  java_home=$(readlink -f $(which java) | xargs dirname | xargs dirname)
  find $java_home -name cacerts
}


#-------------------------
# main
#------------------------

if [ -z $1 ]; then echo "Argument 1 must be the Java trust store password"; exit 1; fi
if [ -z $2 ]; then echo "Argument 2 must be the Ranger admin key store password"; exit 1; fi
if [ -z $3 ]; then echo "Argument 3 must be the Ranger plugin alias"; exit 1; fi
if [ -z $4 ]; then echo "Argument 4 must be the plugin configuration directory"; exit 1; fi
if [ -z $5 ]; then echo "Argument 5 must be the Ranger plugin keystore name"; exit 1; fi
if [ -z $6 ]; then echo "Argument 6 must be the Ranger plugin keystore password"; exit 1; fi
if [ -z $7 ]; then echo "Argument 7 must be the Ranger plugin truststore name"; exit 1; fi
if [ -z $8 ]; then echo "Argument 8 must be the Ranger plugin truststore password"; exit 1; fi

javaTrustPassword=$1
rangerKeyStorePassword=$2
pluginAlias=$3
serviceConfDir=$4
pluginKeystore="$serviceConfDir/$5"
pluginKeyStorePassword=$6
pluginTrustStore="$serviceConfDir/$7"
pluginTrustStorePassword=$8

										# jvm trust store
javaTrustStore=$(getJavaTrustStore)

										# ranger admin info

rangerConfDir="/etc/ranger/admin/conf"
rangerKeyStore="$rangerConfDir/ranger-admin-keystore.jks"
rangerTrustStore="$rangerConfDir/ranger-admin-keystore.jks"
adminAlias="rangeradmin"

                                        # Make the plugin's key and keystore
mkdir -v -p $serviceConfDir
rm -f $pluginKeystore 2>/dev/null
keytool -genkey -keyalg RSA -alias $pluginAlias -keystore $pluginKeystore -storetype JKS -validity 360 -keysize 2048 -storepass $pluginKeyStorePassword -keypass $pluginKeyStorePassword -dname "CN=$pluginAlias,OU=FCI,O=IBM"
ls -l $pluginKeystore

                                        # Import the admins's cert into the plugin's trust store
                                        # (ranger-plugin-truststore.jks)

keytool -export -keystore $rangerKeyStore -alias $adminAlias -file /tmp/$adminAlias.cer -storepass $rangerKeyStorePassword
[ -e $pluginTrustStore ] && keytool -delete -alias $adminAlias -keystore $pluginTrustStore -storepass $pluginTrustStorePassword 2>/dev/null
keytool -import -file /tmp/$adminAlias.cer -alias $adminAlias -keystore $pluginTrustStore -storepass $pluginTrustStorePassword -noprompt

rm -f /tmp/$adminAlias.cer

                                        # add the plugin cert to the JVM trust store and the Admin trust store

keytool -export -keystore $pluginKeystore -alias $pluginAlias -file /tmp/$pluginAlias.cer -storepass $pluginKeyStorePassword
keytool -delete -alias $pluginAlias -keystore $javaTrustStore -storepass $javaTrustPassword 2>/dev/null
keytool -import -file /tmp/$pluginAlias.cer -alias $pluginAlias -keystore $javaTrustStore -storepass $javaTrustPassword -noprompt

keytool -delete -alias $pluginAlias -keystore $rangerTrustStore -storepass $rangerKeyStorePassword 2>/dev/null
keytool -import -file /tmp/$pluginAlias.cer -alias $pluginAlias -keystore $rangerTrustStore -storepass $rangerKeyStorePassword -noprompt

rm -f /tmp/$pluginAlias.cer
