#!/bin/sh
##################################################################
# Licensed Materials - Property of IBM
#
# IBM Financial Crimes Insight with Watson PID 5900-A0H
# IBM Financial Crimes Insight with Watson, Private PID 5737-E41
#
# (C) Copyright IBM Corp. 2017, 2018
#
# US Government Users Restricted Rights - Use, duplication or
# disclosure restricted by GSA ADP Schedule Contract with
# IBM Corp.
##################################################################
# Timestamp
timestamp () {
	date +"%F_%T"
}

# Capture the current working directory
SCRIPT_DIR=$(cd -P -- "$(dirname -- "$0")" && pwd -P)

# Input variables
AMBARI_HOSTNAME=$1		  # Ambari hostname
AMBARI_VERSION=$2       # Ambari build version (i.e. 2.6.1.5-3)
#AMBARI_PORT=$3			    # Port
#AMBARI_SECURE_PORT=$4	# Secure port

# Set aliases
alias log.info='echo [$(timestamp)][INFO][line $LINENO] ${INSTALL_STEP} - [HDP] '
alias log.error='echo [$(timestamp)][ERROR][line $LINENO] ${INSTALL_STEP} - [HDP] '
alias log.warn='echo [$(timestamp)][WARNING][line $LINENO] ${INSTALL_STEP} - [HDP] '

# Set defaults if not set
[[ "${AMBARI_HOSTNAME}" = "" ]]     && AMBARI_HOSTNAME="`hostname -f`"
#[[ "${AMBARI_PORT}" = "" ]]     		&& AMBARI_PORT="8440"
#[[ "${AMBARI_SECURE_PORT}" = "" ]]     && AMBARI_SECURE_PORT="8441"

##################################################################

echo
INSTALL_STEP="Install Ambari Agent"
log.info "Installing Ambari agent on `hostname -f`."

# Create Ambari repo file in /etc/yum.repos.d
log.info "Creating Ambari repository in /etc/yum.repos.d/."
cat << 'EOF' > /etc/yum.repos.d/ambari.repo
[ambari]
name=Ambari AMBARI_VERSION
baseurl=http://REPO_HOSTNAME/repos/ambari/centos7/AMBARI_VERSION/
gpgcheck=0
enabled=1
priority=1
EOF

# Add HTTP Server hostname
log.info "Updating Ambari repository with HTTP server name - $AMBARI_HOSTNAME."
sed -i -e "s/REPO_HOSTNAME/$AMBARI_HOSTNAME/g" /etc/yum.repos.d/ambari.repo

# Add Ambari version
log.info "Updating Ambari repository with Ambari version - $AMBARI_VERSION."
sed -i -e "s/AMBARI_VERSION/$AMBARI_VERSION/g" /etc/yum.repos.d/ambari.repo

# Install public key
log.info "Import public key for Ambari rpm packages."
rpm --import http://$AMBARI_HOSTNAME/repos/ambari/centos7/$AMBARI_VERSION/RPM-GPG-KEY/RPM-GPG-KEY-Jenkins

# Install Ambari server
log.info "=================================================================================="
log.info "Installing Ambari agent on `hostname -f`."
log.info "=================================================================================="
yum install -q -y ambari-agent

# Update Ambari agent configuration
log.info "Updating Ambari agent configuration with Ambari server hostname $AMBARI_HOSTNAME"
sed -i -e "s/^hostname=.*$/hostname=${AMBARI_HOSTNAME}/g" /etc/ambari-agent/conf/ambari-agent.ini
sed -i -e "/credential_shell/i\\force_https_protocol=PROTOCOL_TLSv1_2" /etc/ambari-agent/conf/ambari-agent.ini
# Updating Log File Location
sed -i -e "s#/var/log/ambari-agent#/hadoop/log/ambari-agent#g" /etc/ambari-agent/conf/ambari-agent.ini


# Start Ambari agent
log.info "Starting Ambari agent on `hostname -f`"
echo
ambari-agent start || { log.error "Unable to start Ambari agent on `hostname -f`." && echo; exit 1; }
echo
