import sys
import json
import pickle
import re

def returnToBash(fciObjectResult):
    print(fciObjectResult)
    sys.exit(0)

def returnListToBash(fciObjectResult):
    print ", ".join(fciObjectResult)
    sys.exit(0)


if __name__ == '__main__':
    from create_fci_cluster_object import *
    args = sys.argv
    request = args[1].split(" ")
    
    if len(request) < 2 and request[0] != "TEST":
        print("ERROR: Invalid Request -> {}".format(args[1]))
        sys.exit(1)
    
    request_type = request[0]   # Operation/query type for the information we want to return. Ex: get, add, set...
    
    if request_type != "TEST":
        request_operation = request[1] # Request operation type. Example: SERVICE_LOCATION, NODE_SERVER, TOPOLOGY, etc...
        
        '''
        Object the request should be performed on.
        Example 1: If in the case where user wishes to get the ambari server, it would be AMBARI (whole message of: GET NODE_SERVER AMBARI)
        Example 2: If in the case where user wishes to get flume service node location, it could be FLUME (whole message of: GET SERVICE_LOCATION FLUME)
        '''
        request_subject = request[2]
    
    with open("fci_cluster.pkl", "rb") as file:
        fci_object = pickle.load(file)
    
    
    '''
    Request Type - GET
    Accepted Request Operations for Request Type GET:
    - NODE_SERVER : Get the server for the specified node type
    - NODE_IPADDRESS : Get the ipaddress for the specified node type
    - SERVICE_HOST : Get the host servers where a service is located in the blueprint. This will query the blueprint for service host group location
                     and then get the server for the service from the cluster template.
    - TOPOLOGY - Gets information specific to the topology
    
    Accepted Request Subject for each Request Operation:
    - NODE_SERVER : all, ambari, master, secondary, gateway, slave (case does not matter)
    - SERVICE_HOST : any service that is defined in the components list in the blueprint
    - Topology : type (will be prod or dev)
    
    --------------------------------
    
    Request Type = CHECK
    - This is for any kind of check we wish to do with the blueprint, cluster template, or properties files.
    
    Accepted Request Operations:
    - HOST : Used when we want to do a check for host properties or information
    
    Accepted Request Subject for each Request Operation:
    HOST:
      - ASSIGNMENT : Used to check that a host is not specified in more than one group, and that the total number of hosts
                     is the same as the number of unique hosts specified (i.e. the total hosts in all groups is the same as the number of unique hosts).
    
    --------------------------------
    
    Request Type - TEST
    - This is simply a test function to make sure the Python FCI CLUSTER object was loaded correctly by this script and can be used.
    '''

    if request_type == "GET":
        if request_operation == "NODE_SERVER":
            if request_subject.lower() == "all":
                servers = fci_object.getAllClusterServers()
            else:
                servers = fci_object.getHostGroupServers(request_subject.lower())
            returnListToBash(servers)
        elif request_operation == "NODE_IPADDRESS":
            if request_subject.lower() == "all":
                ipaddress = fci_object.getAllClusterIpAddresses()
            else:
                ipaddress = fci_object.getHostGroupIPAddress(request_subject.lower())
            returnListToBash(ipaddress)
        elif request_operation == "SERVICE_HOST":
            # Here the request_subject is the service we want the hosts for
            returnListToBash(fci_object.getBlueprintServiceHostServers(request_subject.upper()))
        elif request_operation == "TOPOLOGY":
            if request_subject == "TYPE":
                returnToBash(fci_object.getTopologyType())
    
    elif request_type == "CHECK":
        if request_operation == "HOST":
            if request_subject == "ASSIGNMENT":
                returnToBash(fci_object.checkHostGroupAssignment())
    
    elif request_type == "TEST":
        returnToBash(fci_object.test())

